==> Mfuzz_2.10.0.zip: Mfuzz/doc/Mfuzz.R <==
###################################################
### chunk number 1: 
###################################################
#line 42 "Mfuzz.Rnw"
  library(Mfuzz) 


###################################################
### chunk number 2: 
###################################################
#line 54 "Mfuzz.Rnw"
  data(yeast) 


###################################################
### chunk number 3: 
###################################################
#line 63 "Mfuzz.Rnw"
yeast.r <- filter.NA(yeast, thres=0.25)


###################################################
### chunk number 4: 
###################################################
#line 73 "Mfuzz.Rnw"
yeast.f <- fill.NA(yeast.r,mode="mean")


###################################################
### chunk number 5:  eval=FALSE
###################################################
## #line 92 "Mfuzz.Rnw"
##   tmp <- filter.std(yeast.f,min.std=0)  


###################################################
### chunk number 6: 
###################################################
#line 116 "Mfuzz.Rnw"
yeast.s <- standardise(yeast.f)


###################################################
### chunk number 7:  eval=FALSE
###################################################
## #line 151 "Mfuzz.Rnw"
##  cl <- mfuzz(yeast.s,c=16,m=1.25)
##  mfuzz.plot(yeast.s,cl=cl,mfrow=c(4,4),time.labels=seq(0,160,10))


###################################################
### chunk number 8:  eval=FALSE
###################################################
## #line 212 "Mfuzz.Rnw"
##    cl2 <- mfuzz(yeast.s,c=16,m=1.35)
##    mfuzz.plot(yeast.s,cl=cl2,mfrow=c(4,4),time.labels=seq(0,160,10))


###################################################
### chunk number 9:  eval=FALSE
###################################################
## #line 243 "Mfuzz.Rnw"
## O <- overlap(cl)
## Ptmp <- overlap.plot(cl,over=O,thres=0.05)


###################################################
### chunk number 10:  eval=FALSE
###################################################
## #line 251 "Mfuzz.Rnw"
## cl3 <- mfuzz(yeast.s,c=10,m=1.25)
## mfuzz.plot(yeast.s,cl=cl3,mfrow=c(3,4))
## O3 <- overlap(cl3)
## overlap.plot(cl3,over=O3,P=Ptmp,thres=0.05)


###################################################
### chunk number 11:  eval=FALSE
###################################################
## #line 268 "Mfuzz.Rnw"
## cl4 <- mfuzz(yeast.s,c=25,m=1.25)
## mfuzz.plot(yeast.s,cl=cl4,mfrow=c(5,5))
## O4 <- overlap(cl4)
## overlap.plot(cl4,over=O4,P=Ptmp,thres=0.05)

==> Mfuzz_2.12.0.zip: Mfuzz/doc/Mfuzz.R <==
### R code from vignette source 'Mfuzz.Rnw'

###################################################
### code chunk number 1: Mfuzz.Rnw:41-42
###################################################
  library(Mfuzz) 


###################################################
### code chunk number 2: Mfuzz.Rnw:53-54
###################################################
  data(yeast) 


###################################################
### code chunk number 3: Mfuzz.Rnw:62-63
###################################################
yeast.r <- filter.NA(yeast, thres=0.25)


###################################################
### code chunk number 4: Mfuzz.Rnw:72-73
###################################################
yeast.f <- fill.NA(yeast.r,mode="mean")


###################################################
### code chunk number 5: Mfuzz.Rnw:91-92 (eval = FALSE)
###################################################
##   tmp <- filter.std(yeast.f,min.std=0)  


###################################################
### code chunk number 6: Mfuzz.Rnw:115-116
###################################################
yeast.s <- standardise(yeast.f)


###################################################
### code chunk number 7: Mfuzz.Rnw:150-152 (eval = FALSE)
###################################################
##  cl <- mfuzz(yeast.s,c=16,m=1.25)
##  mfuzz.plot(yeast.s,cl=cl,mfrow=c(4,4),time.labels=seq(0,160,10))


###################################################
### code chunk number 8: Mfuzz.Rnw:211-213 (eval = FALSE)
###################################################
##    cl2 <- mfuzz(yeast.s,c=16,m=1.35)
##    mfuzz.plot(yeast.s,cl=cl2,mfrow=c(4,4),time.labels=seq(0,160,10))


###################################################
### code chunk number 9: Mfuzz.Rnw:242-244 (eval = FALSE)
###################################################
## O <- overlap(cl)
## Ptmp <- overlap.plot(cl,over=O,thres=0.05)


###################################################
### code chunk number 10: Mfuzz.Rnw:250-254 (eval = FALSE)
###################################################
## cl3 <- mfuzz(yeast.s,c=10,m=1.25)
## mfuzz.plot(yeast.s,cl=cl3,mfrow=c(3,4))
## O3 <- overlap(cl3)
## overlap.plot(cl3,over=O3,P=Ptmp,thres=0.05)


###################################################
### code chunk number 11: Mfuzz.Rnw:267-271 (eval = FALSE)
###################################################
## cl4 <- mfuzz(yeast.s,c=25,m=1.25)
## mfuzz.plot(yeast.s,cl=cl4,mfrow=c(5,5))
## O4 <- overlap(cl4)
## overlap.plot(cl4,over=O4,P=Ptmp,thres=0.05)
